@@ -1,12 +1,17 @@
-# Setup logging globally (ie root logger)
+#!/usr/bin/env python
+"""
+StarCluster logging module
+"""
 import types
 import logging
 import logging.handlers
-import platform
+from logging import INFO, DEBUG, WARN, ERROR, FATAL
+
+from starcluster import static
 
 INFO_NO_NEWLINE = logging.INFO + 1
 
-class MultipleFormatHandler(logging.StreamHandler):
+class ConsoleLogger(logging.StreamHandler):
 
     formatters = {  logging.INFO: logging.Formatter(">>> %(message)s\n"),
                     INFO_NO_NEWLINE: logging.Formatter(">>> %(message)s"),
@@ -35,14 +40,29 @@ class MultipleFormatHandler(logging.StreamHandler):
         except:
             self.handleError(record)
 
-logger = logging.getLogger('starcluster')
-logger.setLevel(logging.INFO)
+log = logging.getLogger('starcluster')
+log.setLevel(logging.DEBUG)
 
-mfh = MultipleFormatHandler()
-logger.addHandler(mfh)
+formatter = logging.Formatter("%(filename)s:%(lineno)d - %(levelname)s - %(message)s")
 
-if platform.system() == "Linux":
-    syslog_handler = logging.handlers.SysLogHandler(address='/dev/log')
-    formatter = logging.Formatter("%(filename)s:%(lineno)d - %(levelname)s - %(message)s\n")
-    syslog_handler.setFormatter(formatter)
-    logger.addHandler(syslog_handler)
+rfh = logging.handlers.RotatingFileHandler(static.DEBUG_FILE,
+                                           maxBytes=1048576,
+                                           backupCount=2)
+rfh.setLevel(logging.DEBUG)
+rfh.setFormatter(formatter)
+log.addHandler(rfh)
+
+console = ConsoleLogger()
+console.setLevel(logging.INFO)
+log.addHandler(console)
+
+#import platform
+#if platform.system() == "Linux":
+    #import os
+    #log_device = '/dev/log'
+    #if os.path.exists(log_device):
+        #log.debug("Logging to %s" % log_device)
+        #syslog_handler = logging.handlers.SysLogHandler(address=log_device)
+        #syslog_handler.setFormatter(formatter)
+        #syslog_handler.setLevel(logging.DEBUG)
+        #log.addHandler(syslog_handler)
